@@ -243,7 +243,8 @@ COL_EMBLEM, COL_EMBLEM_SECONDARY, COL_SIZE, COL_TIME, COL_PERMS, COL_END = \
 
 class DirDiffTreeStore(tree.DiffTreeStore):
     def __init__(self, ntree):
-        super().__init__(ntree, [str, str, int, float, int])
+        # FIXME: size should be a GObject.TYPE_UINT64, but we use -1 as a flag
+        super().__init__(ntree, [str, str, GObject.TYPE_INT64, float, int])
 
     def add_error(self, parent, msg, pane):
         defaults = {
@@ -669,7 +670,7 @@ class DirDiff(MeldDoc, Component):
         # the time we get this far. This is a fallback, and may be wrong!
         locations = list(locations)
         for i, l in enumerate(locations):
-            if not isinstance(l, str):
+            if l and not isinstance(l, str):
                 locations[i] = l.decode(sys.getfilesystemencoding())
         locations = [os.path.abspath(l) if l else '' for l in locations]
         self.current_path = None
@@ -1384,7 +1385,7 @@ class DirDiff(MeldDoc, Component):
         ]
 
         existing_times = [s.st_mtime for s in stats if s]
-        newest_time = max(existing_times)
+        newest_time = max(existing_times) if existing_times else 0
         if existing_times.count(newest_time) == len(existing_times):
             # If all actually-present files have the same mtime, don't
             # pretend that any are "newer", and do the same if e.g.,
@@ -1427,9 +1428,12 @@ class DirDiff(MeldDoc, Component):
                     COL_EMBLEM: emblem,
                     COL_EMBLEM_SECONDARY: link_emblem,
                     COL_TIME: times[j],
-                    COL_SIZE: sizes[j],
                     COL_PERMS: perms[j]
                 })
+                # Size is handled independently, because unsafe_set
+                # can't correctly box GObject.TYPE_INT64.
+                self.model.set(
+                    it, self.model.column_index(COL_SIZE, j), sizes[j])
             else:
                 self.model.set_path_state(
                     it, j, tree.STATE_NONEXIST, any(isdir))
